@@ -11,7 +11,7 @@ __license__ = 'MIT'
 def __init():
     """Package init wrapper.
     """
-    from pytsite import console, events, lang
+    from pytsite import console, events, lang, tpl
     from . import _commands, _functions
 
     def app_update_event():
@@ -27,4 +27,10 @@ def __init():
     events.listen('pytsite.router.dispatch', _functions.reset)
     events.listen('pytsite.update.after', app_update_event)
 
+    tpl.register_global('asset_url', url)
+    tpl.register_global('assetman_add', add)
+    tpl.register_global('assetman_css', dump_css)
+    tpl.register_global('assetman_js', dump_js)
+    tpl.register_global('assetman_inline', dump_inline)
+
 __init()
