@@ -2,7 +2,7 @@
 """
 import time as _time
 from os import listdir as _listdir, path as _path, unlink as _unlink
-from pytsite import logger as _logger, reg as _reg, router as _router
+from pytsite import logger as _logger, reg as _reg
 
 __author__ = 'Alexander Shepetko'
 __email__ = 'a@shepetko.com'
@@ -27,11 +27,12 @@ def _clean_tmp_files():
 
 
 def _clean_sessions():
+    session_path = _reg.get('paths.session')
     ttl = int(_reg.get('router.session.ttl', 21600))  # 6 hours
-    _logger.info('Cleaning up old session data in {}'.format(_router.session_storage_path), __name__)
+    _logger.info('Cleaning up old session data in {}'.format(session_path), __name__)
 
-    for file_name in _listdir(_router.session_storage_path):
-        file_path = _path.join(_router.session_storage_path, file_name)
+    for file_name in _listdir(session_path):
+        file_path = _path.join(session_path, file_name)
         if _path.isfile(file_path) and (_time.time() - _path.getmtime(file_path)) >= ttl:
             _logger.info('Removing {}'.format(file_path), __name__)
             _unlink(file_path)
