@@ -3,7 +3,7 @@
 # Public API
 from . import _model as model, _error as error
 from ._driver import Abstract as AbstractDriver
-from ._functions import register_driver
+from ._api import register_driver
 
 __author__ = 'Alexander Shepetko'
 __email__ = 'a@shepetko.com'
@@ -23,7 +23,7 @@ def __init():
     odm.register_model('content_export', _model.ContentExport)
 
     # Event handlers
-    events.listen('pytsite.cron.1min', _eh.cron_1min_eh)
+    events.listen('pytsite.cron.1min', _eh.cron_1min)
 
     # Sidebar menu
     m = 'content_export'
