@@ -14,9 +14,11 @@ def authorize(args: dict, inp: dict):
     # Checking for errors
     error = inp.get('error_description')
     if error:
-        _router.session.add_error(error)
+        _router.session().add_error(error)
 
-    # initializing authorization session
-    session = _AuthSession(inp.get('state'))
+    # Initializing authorization session
+    auth_session = _AuthSession(inp.get('state'))
 
-    return _http.response.Redirect(_router.url(session.final_redirect_uri, query=inp))
+    print('---' + auth_session.redirect_uri)
+
+    return _http.response.Redirect(_router.url(auth_session.redirect_uri, query=inp))
