@@ -19,7 +19,7 @@ def __init():
     assetman.register_package(__name__)
 
     # Register Content Export driver
-    content_export.register_driver('lj', __name__ + '@livejournal', ContentExportDriver)
+    content_export.register_driver(ContentExportDriver())
 
 
 __init()
