@@ -20,12 +20,12 @@ if not _path.exists(_log_dir):
 _format = '%(asctime)s %(levelname)s %(message)s'
 _logging.basicConfig(filename=_log_path, datefmt='%Y-%m-%d %H:%M:%S', format=_format)
 _logger = _logging.getLogger(_reg.get('env.name', 'default'))
-_level = _logging.DEBUG if _reg.get('logger.level') == 'debug' else _logging.INFO
+_level = _logging.DEBUG if _reg.get('debug.enabled') else _logging.INFO
 _logger.setLevel(_level)
 
 
 def debug(msg: str, prefix: str=None):
-    """Log an DEBUG message.
+    """Log a DEBUG message.
     """
     if prefix:
         msg = '{} {}'.format(prefix, msg)
@@ -43,7 +43,7 @@ def info(msg: str, prefix: str=None):
 
 
 def warn(msg: str, prefix: str=None):
-    """Log an WARNING message.
+    """Log a WARNING message.
     """
     if prefix:
         msg = '{} {}'.format(prefix, msg)
