@@ -2,7 +2,8 @@
 """
 # Public API
 from . import _functions, _model as model, _widget as widget
-from ._functions import register_model, is_model_registered, find, dispense
+from ._functions import register_model, is_model_registered, find, dispense, build_alias_str, find_by_title, \
+    find_by_alias
 
 __author__ = 'Alexander Shepetko'
 __email__ = 'a@shepetko.com'
