@@ -13,17 +13,17 @@ def __init():
     from ._content_export import Driver as ContentExportDriver
 
     if not reg.get('vk.app_id'):
-        raise Exception("'vk.app_id' configuration option must be defined.")
+        raise Exception("'vk.app_id' configuration option should be defined.")
 
     if not reg.get('vk.app_secret'):
-        raise Exception("'vk.app_secret' configuration option must be defined.")
+        raise Exception("'vk.app_secret' configuration option should be defined.")
 
     # Register resources
     lang.register_package(__name__)
     assetman.register_package(__name__)
 
     # Register Content Export driver
-    content_export.register_driver('vk', __name__ + '@vkontakte', ContentExportDriver)
+    content_export.register_driver(ContentExportDriver())
 
     # Event handlers
     events.listen('pytsite.odm.entity.pre_save.content_export', _eh.odm_entity_pre_save_content_export)
